@@ -130,6 +130,7 @@ example administration repository rules and an admin user and group.
    UPDATE_HTTP_INFO = "Updating server info for dumb HTTP transport",
    UPDATE_LASTMOD_DATE = "Updating last-modified date",
    RUNNING_POST_RECEIVE_HOOK = "Running repository post-receive hook",
+   WARN_HEAD_DANGLING = "HEAD remains dangling",
 
    -- Messages from pre-receive
    RUNNING_PRE_RECEIVE_HOOK = "Running repository pre-receive hook",
@@ -162,7 +163,8 @@ example administration repository rules and an admin user and group.
    BYPASS_USER_BANNER_HEADER = "**** ALERT **** ALERT ****  PAY CAREFUL ATTENTION  **** ALERT **** ALERT ****",
    BYPASS_USER_ALERT_MESSAGE = "**** You are acting as the bypass user.  Rules and hooks WILL NOT APPLY  ****",
    BYPASS_USER_BANNER_FOOTER = "**** ALERT **** ALERT **** DO NOT DO THIS NORMALLY **** ALERT **** ALERT ****",
-
+   PREAUTH_CMDLINE_HOOK_DECLINED = "Pre-authorization command line hook declined to permit action: ${reason}",
+   PREAUTH_CMDLINE_HOOK_ABORTED = "Pre-authorization command line hook aborted: ${reason}",
    -- Messages from the config module
    NO_SITE_CONF = "No site.conf",
    NO_CORE_RULES = "No core rules file",
