@@ -34,6 +34,7 @@ local util = require "gitano.util"
 local log = require "gitano.log"
 local gall = require "gall"
 local config = require "gitano.config"
+local pat = require "gitano.patterns"
 local i18n = require 'gitano.i18n'
 local sio = require 'luxio.simple'
 local supple = require 'gitano.supple'
@@ -84,7 +85,7 @@ local function _curl_txn(url, headers, body, content_type)
       return "500", "headers must be a table if provided", {} , ""
    end
    if method == "POST" then
-      headers["Content-Type"] = content_type or application/octet-stream
+      headers["Content-Type"] = content_type or "application/octet-stream"
       headers["Content-Length"] = tostring(#body)
       args[#args+1] = "--data-binary"
       args[#args+1] = "@-"
@@ -106,9 +107,9 @@ local function _curl_txn(url, headers, body, content_type)
    if (how ~= "exit" or why ~= 0) then
       return "500", err, {}, ""
    end
-   local code, msg, _headers, content = response:match("^HTTP/1.[01] (...) ?([^\r\n]+)\r?\n(.-)\r?\n\r?\n(.*)$")
+   local code, msg, _headers, content = response:match(pat.HTTP_RESPONSE)
    local headers = {}
-   for k, v in _headers:gmatch("([^:\r\n]+): *([^\r\n]+)") do
+   for k, v in _headers:gmatch(pat.HTTP_HEADER) do
       local r = headers[k] or {}
       r[#r+1] = v
       headers[k] = r
