@@ -34,6 +34,7 @@ local log = require 'gitano.log'
 local util = require 'gitano.util'
 local repository = require 'gitano.repository'
 local config = require 'gitano.config'
+local pat = require 'gitano.patterns'
 local clod = require 'clod'
 local luxio = require 'luxio'
 local sio = require 'luxio.simple'
@@ -123,6 +124,37 @@ local function builtin_as_run(conf, _, cmdline, env)
    return cmdline.cmd.run(conf, cmdline.repo, cmdline.copy, env)
 end
 
+local function update_user_in_htpasswd(conf, userfrom, userto)
+   if conf.clod.settings["use_htpasswd"] ~= "yes" then
+      return
+   end
+   local htpasswd_path = os.getenv("HOME") .. "/htpasswd"
+   local lock = util.lockfile(htpasswd_path .. ".lock")
+   local fh = io.open(htpasswd_path, "r")
+   if not fh then return end
+   local to_write = {}
+   for l in fh:lines() do
+      if l:sub(1, #userfrom + 1) == userfrom .. ":" then
+         if userto then
+            to_write[#to_write + 1] = userto .. ":" .. l:sub(#userfrom + 2, -1)
+         end
+      else
+         to_write[#to_write+1] = l
+      end
+   end
+   fh:close()
+   fh = assert(io.open(htpasswd_path .. ".new", "w"))
+   fh:write(table.concat(to_write, "\n"))
+   fh:write("\n")
+   fh:close()
+   local ok, errno = luxio.rename(htpasswd_path .. ".new", htpasswd_path)
+   if ok ~= 0 then
+      log.warn(i18n.expand("ERROR_UNABLE_TO_RENAME_INTO_PLACE",
+                           {what="htpasswd", reason=luxio.strerror(errno)}))
+   end
+   util.unlockfile(lock)
+end
+
 local builtin_user_short = "Manage users in Gitano"
 local builtin_user_helptext = [[
 usage: user [list]
@@ -176,7 +208,7 @@ local function builtin_user_validate(conf, _, cmdline)
       log.error("user add takes a username, email address and real name")
       return false
    end
-   if cmdline[2] == "add" and not cmdline[3]:match("^[a-z][a-z0-9_.-]+$") then
+   if cmdline[2] == "add" and not cmdline[3]:match(pat.VALID_USERNAME) then
       log.error("user name '" .. cmdline[3] .. "' not valid.")
       return false
    end
@@ -343,6 +375,23 @@ local function builtin_user_run(conf, _, cmdline, env)
          log.fatal(commit)
       end
       log.state("Committed: " .. reason)
+      if cmdline[2] == "rename" then
+         update_user_in_htpasswd(conf, cmdline[3], cmdline[4])
+         local function reown_repo(_, repo)
+            if repo:conf_get("project.owner") == cmdline[3] then
+               local ok, msg = repo:conf_set_and_save(
+                  "project.owner", cmdline[4],
+                  env.GITANO_USER, env.GITANO_ORIG_USER)
+               if not ok then
+                  log.error(msg)
+                  return "exit", 1
+               end
+            end
+         end
+         repository.foreach(conf, reown_repo)
+      elseif cmdline[2] == "del" then
+         update_user_in_htpasswd(conf, cmdline[3], nil)
+      end
    end
    return "exit", 0
 end
@@ -406,7 +455,7 @@ local function builtin_group_validate(conf, _, cmdline)
       log.error("Add takes a group name and a description")
       return false
    end
-   if cmdline[2] == "add" and not cmdline[3]:match("^[a-z][a-z0-9_.-]+$") then
+   if cmdline[2] == "add" and not cmdline[3]:match(pat.VALID_GROUPNAME) then
       log.error("group name '" .. cmdline[3] .. "' not valid.")
       return false
    end
@@ -739,7 +788,7 @@ local function builtin_keyring_validate(conf, _, cmdline)
       if #cmdline > 3 then
          local ok = true
          for i = 4, #cmdline do
-            if not cmdline[i]:match("^" .. string.rep("[0-9A-Fa-f]", 40) .. "$") then
+            if not cmdline[i]:match(pat.VALID_KEY_FINGERPINRT) then
                log.error("error: '" .. cmdline[i] .. "' is not a valid fingerprint")
                ok = false
             end
@@ -750,7 +799,7 @@ local function builtin_keyring_validate(conf, _, cmdline)
    end
    if cmdline[2] == "delkey" then
       if #cmdline == 4 or #cmdline == 5 then
-         if not cmdline[4]:match("^" .. string.rep("[0-9A-Fa-f]", 40) .. "$") then
+         if not cmdline[4]:match(pat.VALID_KEY_FINGERPRINT) then
             log.error("error: '" .. cmdline[i] .. "' is not a valid fingerprint")
             return false
          end
@@ -795,7 +844,7 @@ local function builtin_keyring_run(conf, _, cmdline, env)
          log.error("Keyring " .. keyringname .. " already exists")
          return "exit", 1
       end
-      if not keyringname:match("^[a-z][a-z0-9_.-]+$") then
+      if not keyringname:match(pat.VALID_KEYRING_NAME) then
          log.error("Keyring " .. keyringname .. " is not lower-alphanumeric")
          return "exit", 1
       end
@@ -867,7 +916,7 @@ local function builtin_keyring_run(conf, _, cmdline, env)
       if code ~= 0 then
          log.fatal("Unable to list keyring: GPG returned " .. tostring(code))
       end
-      for fingerprint in alloutput:gmatch("fpr:::::::::([0-9A-F]+):") do
+      for fingerprint in alloutput:gmatch(pat.GPG_OUTPUT_FINGERPRINT_MATCH) do
          log.stdout(fingerprint)
       end
    end
@@ -1149,7 +1198,7 @@ local function builtin_graveyard_run(conf, _, cmdline, env)
       repeat
          e, i = luxio.readdir(dirp)
          if e == 0 then
-            if not i.d_name:find("^%.") then
+            if not i.d_name:find(pat.DOTFILE) then
                log.stdout(i.d_name)
             end
          end
@@ -1200,7 +1249,7 @@ local function builtin_graveyard_run(conf, _, cmdline, env)
       repeat
          e, i = luxio.readdir(dirp)
          if e == 0 then
-            if not i.d_name:find("^%.") then
+            if not i.d_name:find(pat.DOTFILE) then
                if not match or (match == i.d_name) then
                   to_remove[#to_remove+1] = i.d_name
                end
