@@ -33,6 +33,7 @@
 local log = require 'gitano.log'
 local util = require 'gitano.util'
 local repository = require 'gitano.repository'
+local pattern = require 'gitano.patterns'
 
 local sio = require "luxio.simple"
 
@@ -241,7 +242,7 @@ local function builtin_help_run(config, repo, cmdline, env)
       log.state(cmd.name, do_sep(cmd), desc)
       if cmd.helptext then
          log.state("")
-         for line in (cmd.helptext):gmatch("([^\n]*)\n") do
+         for line in (cmd.helptext):gmatch(pattern.TEXT_LINE) do
             log.state("=>", line)
          end
       end
@@ -304,14 +305,7 @@ end
 local function builtin_receive_pack_run(config, repo, cmdline, env)
    local cmdcopy = {"receive-pack", env=env}
    for i = 2, #cmdline do cmdcopy[i] = cmdline[i] end
-   local how, why = repo:git_command(cmdcopy)
-   -- Check that HEAD is now resolvable in the repo
-   if how == "exit" and why == 0 and not repo.git:get("HEAD") then
-      log.warn("")
-      log.warn("HEAD remains dangling")
-      log.warn("")
-   end
-   return how, why
+   return repo:git_command(cmdcopy)
 end
 
 assert(register_cmd("git-receive-pack", nil, nil,
@@ -453,9 +447,9 @@ local function builtin_config_validate(conf, repo, cmdline)
          return false
       end
       cmdline.orig_key = cmdline[4]
-      if cmdline[4]:match("%.%*$") then
+      if cmdline[4]:match(pattern.CONF_ENDS_WILDCARD) then
          -- Doing a wild removal, expand it now
-         local prefix = cmdline[4]:match("^(.+)%.%*$")
+         local prefix = cmdline[4]:match(pattern.CONF_WILDCARD)
          cmdline[4] = nil
          for k in repo.project_config:each(prefix) do
             cmdline[#cmdline+1] = k
@@ -525,7 +519,7 @@ local function builtin_config_run(conf, repo, cmdline, env)
       for i = 1, #slist do
          local key = slist[i]
          local value = repo.project_config.settings[key]
-         local prefix = key:match("^(.+)%.i_[0-9]+$")
+         local prefix = key:match(pattern.CONF_ARRAY_INDEX)
          if prefix then
             local neatkey = prefix .. ".*"
             for i = 4, #cmdline do
@@ -539,7 +533,7 @@ local function builtin_config_run(conf, repo, cmdline, env)
       end
    elseif cmdline[3] == "set" then
       local key, value = cmdline[4], cmdline[5]
-      local vtype, rest = value:match("^([sbi]):(.*)$")
+      local vtype, rest = value:match(pattern.CONF_SET_TYPE_PREFIX)
       if vtype then
          if vtype == "s" then
             value = rest
@@ -839,9 +833,9 @@ local function builtin_ls_run(config, _, cmdline, env)
          pat = pat .. ".*"
       end
       if used_evil then
-         pat = "^/" .. pat .. "%.git$"
+         pat = "^/" .. pat .. pattern.GIT_REPO_SUFFIX
       else
-         pat = "/" .. pat .. "%.git$"
+         pat = "/" .. pat .. pattern.GIT_REPO_SUFFIX
       end
       log.debug("PAT:", pat)
       pats[#pats+1] = pat
