@@ -38,6 +38,7 @@ local gall = require 'gall'
 local log = require 'gitano.log'
 local lace = require 'gitano.lace'
 local i18n = require 'gitano.i18n'
+local pat = require 'gitano.patterns'
 local luxio = require 'luxio'
 local sio = require 'luxio.simple'
 local clod = require 'clod'
@@ -109,7 +110,7 @@ local function parse_admin_config(commit)
    -- Gather the users
    local users = {}
    for filename, obj in pairs(flat_tree) do
-      local prefix, username = filename:match("^(users/.-)([a-z][a-z0-9_.-]+)/user%.conf$")
+      local prefix, username = filename:match(pat.USER_CONF_MATCH)
       if prefix and username then
          if not is_blob(obj) then
             return nil, prefix .. username .. "/user.conf is not a blob?"
@@ -144,7 +145,7 @@ local function parse_admin_config(commit)
    -- Now gather the users' keys
    local all_keys = {}
    for filename, obj in pairs(flat_tree) do
-      local prefix, username, keyname = filename:match("^(users/.-)([a-z][a-z0-9_.-]+)/([a-z][a-z0-9_.-]+)%.key$")
+      local prefix, username, keyname = filename:match(pat.USER_KEY_MATCH)
       if prefix and username and keyname then
          if not users[username] then
             return nil, i18n.expand("ERROR_ORPHAN_KEY",
@@ -158,7 +159,7 @@ local function parse_admin_config(commit)
             return nil, i18n.expand("ERROR_BAD_KEY_NEWLINES", {filename=filename})
          end
 
-         local keytype, keydata, keytag = this_key:match("^([^ ]+) ([^ ]+) ([^ ].*)$")
+         local keytype, keydata, keytag = this_key:match(pat.SSH_KEY_CONTENTS)
          if not (keytype and keydata and keytag) then
             return nil, i18n.expand("ERROR_BAD_KEY_SMELL", {filename=filename})
          end
@@ -190,7 +191,7 @@ local function parse_admin_config(commit)
    -- Now gather the groups
    local groups = {}
    for filename, obj in pairs(flat_tree) do
-      local prefix, groupname = filename:match("^(groups/.-)([a-z][a-z0-9_.-]+)%.conf$")
+      local prefix, groupname = filename:match(pat.GROUP_CONF_MATCH)
       if prefix and groupname then
          if groups[groupname] then
             return nil, i18n.expand("ERROR_DUPLICATE_GROUP", {name=groupname})
@@ -269,7 +270,7 @@ local function parse_admin_config(commit)
    -- Now gather the keyrings
    local keyrings = {}
    for filename, obj in pairs(flat_tree) do
-      local prefix, keyringname = filename:match("^(keyrings/.-)([a-z][a-z0-9_.-]+)%.gpg$")
+      local prefix, keyringname = filename:match(pat.KEYRING_MATCH)
       if prefix and keyringname then
          if keyrings[keyringname] then
             return nil, i18n.expand("ERROR_DUPLICATE_KEYRING", {name=keyringname})
@@ -440,9 +441,9 @@ local function commit_config_changes(conf, desc, author, committer)
 
    -- Shallow copy the tree ready for mods, skipping keyrings, users and groups
    for k,v in pairs(conf.content) do
-      if not (k:match("^users/") or
-                 k:match("^groups/") or
-              k:match("^keyrings/")) then
+      if not (k:match(pat.USER_INFO_PREFIX) or
+                 k:match(pat.GROUP_INFO_PREFIX) or
+              k:match(pat.KEYRING_INFO_PREFIX)) then
          newtree[k] = v
       end
    end
