@@ -35,6 +35,7 @@ local util = require 'gitano.util'
 local gall = require 'gall'
 local log = require 'gitano.log'
 local i18n = require 'gitano.i18n'
+local pat = require 'gitano.patterns'
 
 local pcre = require "rex_pcre"
 
@@ -45,7 +46,7 @@ include global:core
 }
 
 local function _loader(ctx, _name)
-   local global_name = _name:match("^global:(.+)$")
+   local global_name = _name:match(pat.LACE_GLOBAL_DEFINITION)
    local name, tree, sha = global_name or _name
    if not global_name then
       -- Project load
