@@ -34,6 +34,7 @@ local log = require 'gitano.log'
 local util = require 'gitano.util'
 local repository = require 'gitano.repository'
 local config = require 'gitano.config'
+local pat = require 'gitano.patterns'
 
 local sio = require 'luxio.simple'
 local subprocess = require 'luxio.subprocess'
@@ -155,7 +156,7 @@ local function builtin_sshkey_validate(config, _, cmdline)
          log.error("sshkey", cmdline[2] .. ":  Expected tag and no more")
          return false
       end
-      if not cmdline[3]:match("^[a-z][a-z0-9_-]+$") then
+      if not cmdline[3]:match(pat.VALID_SSHKEYNAME) then
          log.error("sshkey:", cmdline[3], "is not a valid tag name.")
          log.state("Tag names start with a letter and may contain only letters")
          log.state("and numbers, underscores and dashes.  Tag names must be at")
@@ -211,7 +212,7 @@ local function builtin_sshkey_run(conf, _, cmdline, env)
       end
    elseif cmdline[2] == "add" then
       local sshkey = sio.stdin:read("*l")
-      local keytype, keydata, keytag = sshkey:match("^([^ ]+) ([^ ]+) ([^ ].*)$")
+      local keytype, keydata, keytag = sshkey:match(pat.SSH_KEY_CONTENTS)
       if not (keytype and keydata and keytag) then
          log.error("Unable to parse key,", filename,
                    "did not smell like an OpenSSH v2 key")
@@ -281,6 +282,7 @@ end
 
 local function update_htpasswd(user, passwd)
    local htpasswd_path = os.getenv("HOME") .. "/htpasswd"
+   local lock = util.lockfile(htpasswd_path .. ".lock")
    local flags = io.open(htpasswd_path, "r") and "-i" or "-ic"
    local exit_code
 
@@ -302,7 +304,7 @@ local function update_htpasswd(user, passwd)
 
       _, exit_code = proc:wait()
    end
-
+   util.unlockfile(lock)
    return exit_code == 0
 end
 
