@@ -569,6 +569,21 @@ local function tempfile(repo)
    return fd, temppattern
 end
 
+local function lockfile(path)
+   local fh = assert(sio.open(path, "cw+"))
+   local ok, msg = fh:lock("w", "set", 0, 0, true, false)
+   if not ok then
+      fh:close()
+      error(msg)
+   end
+   return fh
+end
+
+local function unlockfile(fh)
+   fh:lock("", "set", 0, 0, true, false)
+   fh:close()
+end
+
 return {
    parse_cmdline = _parse_cmdline,
 
@@ -605,4 +620,7 @@ return {
    check_password = check_password,
 
    run_command = run_command,
+
+   lockfile = lockfile,
+   unlockfile = unlockfile,
 }
